//+------------------------------------------------------------------+
//|                                         EMA-Crossover_Signal.mq4 |
//|         Copyright  2005, Jason Robinson (jnrtrading)            |
//|                   http://www.jnrtading.co.uk                     |
//|         Alert & vline were added                                 |
//|                          by TOTO <http://forexer.blog51.fc2.com/>|
//+------------------------------------------------------------------+

/*
  +------------------------------------------------------------------+
  | Allows you to enter two ema periods and it will then show you at |
  | Which point they crossed over. It is more usful on the shorter   |
  | periods that get obscured by the bars / candlesticks and when    |
  | the zoom level is out. Also allows you then to remove the emas   |
  | from the chart. (emas are initially set at 5 and 6)              |
  +------------------------------------------------------------------+
*/   
#property copyright "Copyright  2005, Jason Robinson (jnrtrading)"
#property link      "http://www.jnrtrading.co.uk"

#property indicator_chart_window
#property indicator_buffers 2
#property indicator_color1 LimeGreen
#property indicator_color2 Orange
#property indicator_width1 1
#property indicator_width2 1

double CrossUp[];
double CrossDown[];
extern string note_MaMode = "0=sma;1=ema;2=smma;3=lwma";
extern int FasterMode = 1; //0=sma, 1=ema, 2=smma, 3=lwma
extern int FasterMA =   5;
extern int SlowerMode = 1; //0=sma, 1=ema, 2=smma, 3=lwma
extern int SlowerMA =   6;
extern int UpArrow =   233;
extern int DnArrow =   234;
extern double ArrowDistance=0.5;
extern bool SoundON=true;
extern bool VlineON=true;
extern color VlineColor = White;
double alertTag;
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- indicators
   SetIndexStyle(0, DRAW_ARROW);
   SetIndexArrow(0, UpArrow);
   SetIndexBuffer(0, CrossUp);
   SetIndexStyle(1, DRAW_ARROW);
   SetIndexArrow(1, DnArrow);
   SetIndexBuffer(1, CrossDown);
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//---- 
   DelObj();
//----
   return(0);
  }

void DelObj()
{
	ObjectDelete("ArrowVLine");
}

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start() {
   int limit, i, counter;
   double fasterMAnow, slowerMAnow, fasterMAprevious, slowerMAprevious, fasterMAafter, slowerMAafter;
   double Range, AvgRange;
   int counted_bars=IndicatorCounted();
//---- check for possible errors
   if(counted_bars<0) return(-1);
//---- last counted bar will be recounted
   if(counted_bars>0) counted_bars--;

   limit=Bars-counted_bars;
   
   for(i = 0; i <= limit; i++) {
   
      counter=i;
      Range=0;
      AvgRange=0;
      for (counter=i ;counter<=i+9;counter++)
      {
         AvgRange=AvgRange+MathAbs(High[counter]-Low[counter]);
      }
      Range=AvgRange/10;
       
      fasterMAnow = iMA(NULL, 0, FasterMA, 0, FasterMode, PRICE_CLOSE, i);
      fasterMAprevious = iMA(NULL, 0, FasterMA, 0, FasterMode, PRICE_CLOSE, i+1);
      fasterMAafter = iMA(NULL, 0, FasterMA, 0, FasterMode, PRICE_CLOSE, i-1);

      slowerMAnow = iMA(NULL, 0, SlowerMA, 0, SlowerMode, PRICE_CLOSE, i);
      slowerMAprevious = iMA(NULL, 0, SlowerMA, 0, SlowerMode, PRICE_CLOSE, i+1);
      slowerMAafter = iMA(NULL, 0, SlowerMA, 0, SlowerMode, PRICE_CLOSE, i-1);
      
      if ((fasterMAnow > slowerMAnow) && (fasterMAprevious < slowerMAprevious) && (fasterMAafter > slowerMAafter)) {
         CrossUp[i] = Low[i] - Range*ArrowDistance;
      }
      else if ((fasterMAnow < slowerMAnow) && (fasterMAprevious > slowerMAprevious) && (fasterMAafter < slowerMAafter)) {
         CrossDown[i] = High[i] + Range*ArrowDistance;
      }
      if (SoundON==true && i==1 && CrossUp[i] > CrossDown[i] && alertTag!=Time[0]){
        Alert("MA Crossed Down on ",Symbol()," ",Period());
         alertTag = Time[0];
         DelObj();
         if (VlineON==true){
             ObjectCreate("ArrowVLine",OBJ_VLINE,0,alertTag-1,0); 
             ObjectSet("ArrowVLine",OBJPROP_COLOR,VlineColor); 
             ObjectSet("ArrowVLine",OBJPROP_WIDTH,1); 
             ObjectSet("ArrowVLine",OBJPROP_STYLE,STYLE_DOT);
         } 
      }
      if (SoundON==true && i==1 && CrossUp[i] < CrossDown[i] && alertTag!=Time[0]){
         Alert("MA Crossed Up on ",Symbol()," ",Period());
         alertTag = Time[0];
         DelObj();
         if (VlineON==true){
             ObjectCreate("ArrowVLine",OBJ_VLINE,0,alertTag-1,0); 
             ObjectSet("ArrowVLine",OBJPROP_COLOR,VlineColor); 
             ObjectSet("ArrowVLine",OBJPROP_WIDTH,1); 
             ObjectSet("ArrowVLine",OBJPROP_STYLE,STYLE_DOT);
         } 
      }
   }
   return(0);
}

